@@ -1,22 +1,8 @@
-/***********************************************************************
- * Copyright 2012  Eike Hein <hein@kde.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- ***********************************************************************/
+/*
+    SPDX-FileCopyrightText: 2012 Eike Hein <hein@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "mediaplayer2player.h"
 #include "mainWindow.h"
@@ -25,22 +11,22 @@
 
 #include <QCryptographicHash>
 
-static QByteArray makeTrackId(const QString& source)
+static QByteArray makeTrackId(const QString &source)
 {
-    return QByteArray("/org/kde/") + APP_NAME + "/tid_" +
-            QCryptographicHash::hash(source.toLocal8Bit(), QCryptographicHash::Sha1)
-            .toHex();
+    return QByteArray("/org/kde/") + APP_NAME + "/tid_" + QCryptographicHash::hash(source.toLocal8Bit(), QCryptographicHash::Sha1).toHex();
 }
 
-MediaPlayer2Player::MediaPlayer2Player(QObject* parent) : QDBusAbstractAdaptor(parent)
+MediaPlayer2Player::MediaPlayer2Player(QObject *parent)
+    : QDBusAbstractAdaptor(parent)
+    , oldPos(0)
 {
-    connect(Dragon::engine(), SIGNAL(tick(qint64)), this, SLOT(tick(qint64)));
-    connect(Dragon::engine(), SIGNAL(currentSourceChanged(Phonon::MediaSource)), this, SLOT(currentSourceChanged()));
-    connect(Dragon::engine(), SIGNAL(metaDataChanged()), this, SLOT(emitMetadataChange()));
-    connect(Dragon::engine(), SIGNAL(stateUpdated(Phonon::State,Phonon::State)), this, SLOT(stateUpdated()));
-    connect(Dragon::engine(), SIGNAL(totalTimeChanged(qint64)), this, SLOT(emitMetadataChange()));
-    connect(Dragon::engine(), SIGNAL(seekableChanged(bool)), this, SLOT(seekableChanged(bool)));
-    connect(Dragon::engine(), SIGNAL(volumeChanged(qreal)), this, SLOT(volumeChanged()));
+    connect(Dragon::engine(), &Dragon::VideoWindow::tick, this, &MediaPlayer2Player::tick);
+    connect(Dragon::engine(), &Dragon::VideoWindow::currentSourceChanged, this, &MediaPlayer2Player::currentSourceChanged);
+    connect(Dragon::engine(), &Dragon::VideoWindow::metaDataChanged, this, &MediaPlayer2Player::emitMetadataChange);
+    connect(Dragon::engine(), &Dragon::VideoWindow::stateUpdated, this, &MediaPlayer2Player::stateUpdated);
+    connect(Dragon::engine(), &Dragon::VideoWindow::totalTimeChanged, this, &MediaPlayer2Player::emitMetadataChange);
+    connect(Dragon::engine(), &Dragon::VideoWindow::seekableChanged, this, &MediaPlayer2Player::seekableChanged);
+    connect(Dragon::engine(), &Dragon::VideoWindow::volumeChanged, this, &MediaPlayer2Player::volumeChanged);
 }
 
 MediaPlayer2Player::~MediaPlayer2Player()
@@ -97,7 +83,7 @@ void MediaPlayer2Player::Play() const
     Dragon::engine()->play();
 }
 
-void MediaPlayer2Player::SetPosition(const QDBusObjectPath& TrackId, qlonglong Position) const
+void MediaPlayer2Player::SetPosition(const QDBusObjectPath &TrackId, qlonglong Position) const
 {
     if (TrackId.path().toLocal8Bit() == makeTrackId(Dragon::engine()->urlOrDisc()))
         Dragon::engine()->seek(Position / 1000);
@@ -105,34 +91,34 @@ void MediaPlayer2Player::SetPosition(const QDBusObjectPath& TrackId, qlonglong P
 
 void MediaPlayer2Player::OpenUri(QString Uri) const
 {
-    static_cast<Dragon::MainWindow*>(Dragon::mainWindow())->open(QUrl(Uri));
+    static_cast<Dragon::MainWindow *>(Dragon::mainWindow())->open(QUrl(Uri));
 }
 
 QString MediaPlayer2Player::PlaybackStatus() const
 {
     switch (Dragon::engine()->state()) {
     case (Phonon::PlayingState):
-        return "Playing";
+        return QStringLiteral("Playing");
         break;
     case (Phonon::PausedState):
     case (Phonon::BufferingState):
-        return "Paused";
+        return QStringLiteral("Paused");
         break;
     case (Phonon::StoppedState):
-        return "Stopped";
+        return QStringLiteral("Stopped");
         break;
     default:
-        return "Stopped";
+        return QStringLiteral("Stopped");
         break;
     }
 }
 
 QString MediaPlayer2Player::LoopStatus() const
 {
-    return "None";
+    return QStringLiteral("None");
 }
 
-void MediaPlayer2Player::setLoopStatus(const QString& loopStatus) const
+void MediaPlayer2Player::setLoopStatus(const QString &loopStatus) const
 {
     Q_UNUSED(loopStatus)
 }
@@ -166,19 +152,21 @@ QVariantMap MediaPlayer2Player::Metadata() const
     case Phonon::MediaSource::Empty:
         break;
     default:
-        metaData["mpris:trackid"] = QVariant::fromValue<QDBusObjectPath>(QDBusObjectPath(makeTrackId(Dragon::engine()->urlOrDisc()).constData()));
-        metaData["mpris:length"] = Dragon::engine()->length() * 1000;
-        metaData["xesam:url"] = Dragon::engine()->urlOrDisc();
+        metaData = {
+            {QStringLiteral("mpris:trackid"), QVariant::fromValue<QDBusObjectPath>(QDBusObjectPath(makeTrackId(Dragon::engine()->urlOrDisc()).constData()))},
+            {QStringLiteral("mpris:length"), Dragon::engine()->length() * 1000},
+            {QStringLiteral("xesam:url"), Dragon::engine()->urlOrDisc()},
+        };
     }
 
     QMultiMap<QString, QString> phononMetaData = Dragon::engine()->metaData();
     QMultiMap<QString, QString>::const_iterator i = phononMetaData.constBegin();
 
     while (i != phononMetaData.constEnd()) {
-        if (i.key() == "ALBUM" || i.key() == "TITLE")
-            metaData["xesam:" + i.key().toLower()] = i.value();
-        else if (i.key() == "ARTIST" || i.key() == "GENRE")
-            metaData["xesam:" + i.key().toLower()] = QStringList(i.value());
+        if (i.key() == QLatin1String("ALBUM") || i.key() == QLatin1String("TITLE"))
+            metaData[QLatin1String("xesam:") + i.key().toLower()] = i.value();
+        else if (i.key() == QLatin1String("ARTIST") || i.key() == QLatin1String("GENRE"))
+            metaData[QLatin1String("xesam:") + i.key().toLower()] = QStringList(i.value());
 
         ++i;
     }
@@ -236,44 +224,42 @@ void MediaPlayer2Player::tick(qint64 newPos)
 
 void MediaPlayer2Player::emitMetadataChange() const
 {
-    QVariantMap properties;
-    properties["Metadata"] = Metadata();
+    const QVariantMap properties{{QStringLiteral("Metadata"), Metadata()}};
     Mpris2::signalPropertiesChange(this, properties);
 }
 
 void MediaPlayer2Player::currentSourceChanged() const
 {
-    QVariantMap properties;
-    properties["Metadata"] = Metadata();
-    properties["CanSeek"] = CanSeek();
+    const QVariantMap properties{
+        {QStringLiteral("Metadata"), Metadata()},
+        {QStringLiteral("CanSeek"), CanSeek()},
+    };
     Mpris2::signalPropertiesChange(this, properties);
 }
 
 void MediaPlayer2Player::stateUpdated() const
 {
-    QVariantMap properties;
-    properties["PlaybackStatus"] = PlaybackStatus();
-    properties["CanPause"] = CanPause();
+    const QVariantMap properties{
+        {QStringLiteral("PlaybackStatus"), PlaybackStatus()},
+        {QStringLiteral("CanPause"), CanPause()},
+    };
     Mpris2::signalPropertiesChange(this, properties);
 }
 
 void MediaPlayer2Player::totalTimeChanged() const
 {
-    QVariantMap properties;
-    properties["Metadata"] = Metadata();
+    const QVariantMap properties{{QStringLiteral("Metadata"), Metadata()}};
     Mpris2::signalPropertiesChange(this, properties);
 }
 
 void MediaPlayer2Player::seekableChanged(bool seekable) const
 {
-    QVariantMap properties;
-    properties["CanSeek"] = seekable;
+    const QVariantMap properties{{QStringLiteral("CanSeek"), seekable}};
     Mpris2::signalPropertiesChange(this, properties);
 }
 
 void MediaPlayer2Player::volumeChanged() const
 {
-    QVariantMap properties;
-    properties["Volume"] = Volume();
+    const QVariantMap properties{{QStringLiteral("Volume"), Volume()}};
     Mpris2::signalPropertiesChange(this, properties);
 }
